<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/shop-checkout.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:46 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?3CNpsEkt" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?Z1ykWiMf" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?r9akyhk6" id="font-awesome"></head>

<body class="layout4">

<div class="page-wrapper">

	<!-- Preloader -->
	<div class="preloader"></div>

    <!-- Main Header-->
	<header class="main-header header-style-four inner-page-style">
		<!-- Header Top -->
		<div class="header-top">
			<div class="container">
				<div class="header-top-content">
					<div class="top-left">
						<!-- Info List -->
                        <ul class="info-list">
                            <li>
                                <i class="icon fa-solid fa-wifi"></i>
                                <span>Existing customer? View our exclusive offers for you</span>
                            </li>
                            <li>
                                <a href="#">log in</a>
                            </li>
                        </ul>
					</div>
					<ul class="social-links">
                        <li><span>Follow Us!</span></li>
                        <li><a href="#" title=""><i class="fab fa-facebook"></i></a></li>
                        <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                        <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                    </ul>
				</div>
			</div>
		</div>
		<!-- Header Top -->

        <div class="header-lower">
            <!-- Main box -->
            <div class="main-box">
                <div class="logo-box">
                    <div class="logo d-none d-lg-block"><a href="index.html"><img src="images/logo-v3-white.png" alt="" title="Satnet"></a></div>
                    <div class="logo d-block d-lg-none"><a href="index.html"><img src="images/logo-v4-black.png" alt="" title="Satnet"></a></div>
                </div>

                <!--Nav Box-->
                <div class="nav-outer">    
                    <nav class="nav main-menu">
                        <ul class="navigation">
                            <li class="current dropdown"><a href="index.html">Home</a>
                                <ul>
                                    <li><a href="index.html">Home page 01</a></li>
                                    <li><a href="index-2.html">Home page 02</a></li>
                                    <li><a href="index-3.html">Home page 03</a></li>
                                    <li><a href="index-4.html">Home page 04</a></li>
                                    <li class="dropdown"><a href="#">Single Styles</a>
                                        <ul>
                                            <li><a href="index-1-single.html">Single Style One</a></li>
                                            <li><a href="index-2-single.html">Single Style Two</a></li>
                                            <li><a href="index-3-single.html">Single Style Two</a></li>
                                            <li><a href="index-4-single.html">Single Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Dark Styles</a>
                                        <ul>
                                            <li><a href="index-1-dark.html">Darl Style One</a></li>
                                            <li><a href="index-2-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-3-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-4-dark.html">Darl Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Header Styles</a>
                                        <ul>
                                            <li><a href="index.html">Header Style One</a></li>
                                            <li><a href="index-2.html">Header Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="index-1-rtl.html">RTL Style One</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-services.html">Services</a>
                                <ul>
                                    <li><a href="page-services.html">Services Grid</a></li>
                                    <li><a href="page-service-details.html">Service Details</a></li>
                                </ul>
                            </li>
							<li class="dropdown"><a href="page-about.html">Pages</a>
								<ul>
									<li><a href="page-about.html">About</a></li>
									<li><a href="page-movie.html">Movie</a></li>
									<li><a href="page-pricing.html">Pricing</a></li>
									<li class="dropdown"><a href="shop-products.html">Shop</a>
										<ul>
											<li><a href="shop-products.html">Products</a></li>
											<li><a href="shop-products-sidebar.html">Products Sidebar</a></li>
											<li><a href="shop-product-details.html">Product Details</a></li>
											<li><a href="shop-cart.html">Cart</a></li>
											<li><a href="shop-checkout.html">Checkout</a></li>
										</ul>
									</li>
									<li><a href="page-team.html">Team</a></li>
									<li><a href="page-testimonial.html">Testimonial</a></li>
									<li><a href="page-faq.html">FAQ</a></li>
									<li><a href="page-404.html">Page 404</a></li>
								</ul>
							</li>
							<li class="dropdown"><a href="news-grid.html">News</a>
								<ul>
									<li><a href="news-grid.html">News Grid</a></li>
									<li><a href="news-details.html">News Details</a></li>
								</ul>
							</li>
                            <li><a href="page-contact.html">Contact</a></li>
                        </ul>
                    </nav>
                    <!-- Main Menu End-->
                </div>

                <div class="outer-box">
                    <!-- Header Search -->
						<button class="search-btn">
                            <i class="flaticon-search"></i>
						</button>
						<button class="login-btn">
                            <i class="flaticon-user"></i>
						</button>
                    <a href="#" title="" class="header-btn">Get Connection</a>
                    <div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
                    <!-- Mobile Nav toggler -->
                </div>
            </div>
        </div>
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
		
			<!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header-->
			<nav class="menu-box">
				<div class="upper-box">
					<div class="nav-logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title=""></a></div>
					<div class="close-btn"><i class="icon fa fa-times"></i></div>
				</div>
		
				<ul class="navigation clearfix">
					<!--Keep This Empty / Menu will come through Javascript-->
				</ul>
				<ul class="contact-list-one">
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<i class="icon lnr-icon-phone-handset"></i>
							<span class="title">Call Now</span>
							<a href="tel:+92880098670">+92 (8800) - 98670</a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-envelope1"></span>
							<span class="title">Send Email</span>
							<a href="https://html.kodesolution.com/cdn-cgi/l/email-protection#147c71786454777b7964757a6d3a777b79"><span class="__cf_email__" data-cfemail="4c2429203c0c2f23213c2d2235622f2321">[email&nbsp;protected]</span></a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-clock"></span>
							<span class="title">Send Email</span>
							Mon - Sat 8:00 - 6:30, Sunday - CLOSED
						</div>
					</li>
				</ul>
		
		
				<ul class="social-links">
					<li><a href="#"><i class="fa fa-x"></i></a></li>
					<li><a href="#"><i class="fab fa-facebook-f"></i></a></li>
					<li><a href="#"><i class="fab fa-pinterest"></i></a></li>
					<li><a href="#"><i class="fab fa-instagram"></i></a></li>
				</ul>
			</nav>
		</div><!-- End Mobile Menu -->

		<!-- Header Search -->
		<div class="search-popup">
			<span class="search-back-drop"></span>
			<button class="close-search"><span class="fa fa-times"></span></button>
		
			<div class="search-inner">
				<form method="post" action="https://html.kodesolution.com/2023/satnet-html/index.html">
					<div class="form-group">
						<input type="search" name="search-field" value="" placeholder="Search..." required="">
						<button type="submit"><i class="fa fa-search"></i></button>
					</div>
				</form>
			</div>
		</div>
		<!-- End Header Search -->

		<!-- Sticky Header  -->
		<div class="sticky-header">
			<div class="auto-container">
				<div class="inner-container">
					<!--Logo-->
					<div class="logo">
						<a href="index.html" title=""><img src="images/logo-v2-white.png" alt="" title=""></a>
					</div>
		
					<!--Right Col-->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu">
							<div class="navbar-collapse show collapse clearfix">
								<ul class="navigation clearfix">
									<!--Keep This Empty / Menu will come through Javascript-->
								</ul>
							</div>
						</nav><!-- Main Menu End-->
		
						<!--Mobile Navigation Toggler-->
						<div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
					</div>
				</div>
			</div>
		</div><!-- End Sticky Menu -->
	</header>
	<!--End Main Header -->

	<!-- Start main-content -->
	<section class="page-title" style="background-image: url(images/background/page-title.jpg);">
		<div class="auto-container">
			<div class="title-outer">
				<ul class="page-breadcrumb">
					<li><a href="index.html">Home</a></li>
					<li>Shop</li>
				</ul>
				<h1 class="title">Checkout</h1>
			</div>
		</div>
	</section>
	<!-- end main-content -->

	<!--checkout Start-->
	<section>
		<div class="container pt-70">
			<div class="section-content">
			<form id="checkout-form" action="#">
				<div class="row mt-30">
				<div class="col-md-6">
					<div class="billing-details">
					<h3 class="mb-30">Billing Details</h3>
					<div class="row">
						<div class="mb-3 col-md-6">
						<label for="checkuot-form-fname">First Name</label>
						<input id="checkuot-form-fname" type="email" class="form-control" placeholder="First Name">
						</div>
						<div class="mb-3 col-md-6">
						<label for="checkuot-form-lname">Last Name</label>
						<input id="checkuot-form-lname" type="email" class="form-control" placeholder="Last Name">
						</div>
						<div class="col-md-12">
						<div class="mb-3">
							<label for="checkuot-form-cname">Company Name</label>
							<input id="checkuot-form-cname" type="email" class="form-control" placeholder="Company Name">
						</div>
						<div class="mb-3">
							<label for="checkuot-form-email">Email Address</label>
							<input id="checkuot-form-email" type="email" class="form-control" placeholder="Email Address">
						</div>
						<div class="mb-3">
							<label for="checkuot-form-address">Address</label>
							<input id="checkuot-form-address" type="email" class="form-control" placeholder="Street address">
						</div>
						<div class="mb-3">
							<input type="email" class="form-control" placeholder="Apartment, suite, unit etc. (optional)">
						</div>
						</div>
						<div class="mb-3 col-md-6">
						<label for="checkuot-form-city">City</label>
						<input id="checkuot-form-city" type="email" class="form-control" placeholder="City">
						</div>
						<div class="mb-3 col-md-6">
						<label>State/Province</label>
						<select class="form-control">
							<option>Select Country</option>
							<option>Australia</option>
							<option>UK</option>
							<option>USA</option>
						</select>
						</div>
						<div class="mb-3 col-md-6">
						<label for="checkuot-form-zip">Zip/Postal Code</label>
						<input id="checkuot-form-zip" type="email" class="form-control" placeholder="Zip/Postal Code">
						</div>
						<div class="mb-3 col-md-6">
						<label>Country</label>
						<select class="form-control">
							<option>Select Country</option>
							<option>Australia</option>
							<option>UK</option>
							<option>USA</option>
						</select>
						</div>
					</div>
					</div>
				</div>
				<div class="col-md-6">
					<h3>Additional information</h3>
					<label for="order_comments" class="">Order notes&nbsp;<span class="optional">(optional)</span></label>
					<textarea id="order_comments" class="form-control" placeholder="Notes about your order, e.g. special notes for delivery." rows="3"></textarea>
				</div>
				<div class="col-md-12 mt-30">
					<h3>Your order</h3>
					<table class="table table-striped table-bordered tbl-shopping-cart">
					<thead>
						<tr>
						<th>Photo</th>
						<th>Product Name</th>
						<th>Total</th>
						</tr>
					</thead>
					<tbody>
						<tr>
						<td class="product-thumbnail"><a href="shop-product-details.html"><img alt="product" src="images/resource/products/1.jpg"></a></td>
						<td class="product-name"><a href="shop-product-details.html">Headphone</a> x 2</td>
						<td><span class="amount">$36.00</span></td>
						</tr>
						<tr>
						<td class="product-thumbnail"><a href="shop-product-details.html"><img alt="product" src="images/resource/products/2.jpg"></a></td>
						<td class="product-name"><a href="shop-product-details.html">Lagage</a> x 3</td>
						<td><span class="amount">$115.00</span></td>
						</tr>
						<tr>
						<td class="product-thumbnail"><a href="shop-product-details.html"><img alt="product" src="images/resource/products/3.jpg"></a></td>
						<td class="product-name"><a href="shop-product-details.html">Watch</a> x 1</td>
						<td><span class="amount">$68.00</span></td>
						</tr>
						<tr>
						<td>Cart Subtotal</td>
						<td>&nbsp;</td>
						<td>$180.00</td>
						</tr>
						<tr>
						<td>Shipping and Handling</td>
						<td>&nbsp;</td>
						<td>Free Shipping</td>
						</tr>
						<tr>
						<td>Order Total</td>
						<td>&nbsp;</td>
						<td>$250.00</td>
						</tr>
					</tbody>
					</table>
				</div>
				<div class="col-md-12 mt-60">
					<div class="payment-method">
						<h3>Choose a Payment Method</h3>
						<ul class="accordion-box">
							<li class="accordion block active-block">
								<div class="acc-btn active">
									<div class="icon-outer"><i class="lnr-icon-chevron-down"></i></div>
									Credir Card / Debit Card
								</div>
								<div class="acc-content current">
									<div class="payment-info">
										<div class="row clearfix">
											<div class="col-lg-6 col-md-6 col-sm-12 column">
												<div class="field-input mb-3">
													<input type="text" class="form-control" name="name" placeholder="Name on the Card" required="">
												</div>
											</div>
											<div class="col-lg-6 col-md-6 col-sm-12 column">
												<div class="field-input mb-3">
													<input type="text" class="form-control" name="number" placeholder="Card Number" required="">
												</div>
											</div>
											<div class="col-lg-3 col-md-6 col-sm-12 column">
												<div class="field-input mb-3">
													<input type="text" class="form-control" name="date" placeholder="Expiry Date" required="">
												</div>
											</div>
											<div class="col-lg-3 col-md-6 col-sm-12 column">
												<div class="field-input mb-3">
													<input type="text" class="form-control" name="code" placeholder="Security Code" required="">
												</div>
											</div>
											<div class="col-lg-6 col-md-12 col-sm-12 column">
												<div class="field-input message-btn">
													<button type="submit" class="theme-btn btn-style-one" data-loading-text="Please wait..."><span class="btn-title">Make Payment</span></button>
												</div>
											</div>
										</div>
									</div>
								</div>
							</li>
							<li class="accordion block">
								<div class="acc-btn">
									<div class="icon-outer"><i class="lnr-icon-chevron-down"></i></div>
									Direct Bank Transfer
								</div>
								<div class="acc-content">
									<div class="payment-info">
										<p class="mb-0">Make your payment directly into our bank account. Please use your Order ID as the payment reference. Your order won’t be shipped until the funds have cleared in our account.</p>
									</div>
								</div>
							</li>
							<li class="accordion block">
								 <div class="acc-btn">
									<div class="icon-outer"><i class="lnr-icon-chevron-down"></i></div>
									Cheque Payment
								</div>
								<div class="acc-content">
									<div class="payment-info">
										<p class="mb-0">Make your payment directly into our bank account. Please use your Order ID as the payment reference. Your order won’t be shipped until the funds have cleared in our account.</p>
									</div>
								</div>
							</li>
							<li class="accordion block">
								 <div class="acc-btn">
									<div class="icon-outer"><i class="lnr-icon-chevron-down"></i></div>
									Other Payment
								</div>
								<div class="acc-content">
									<div class="payment-info">
										<p class="mb-0">Make your payment directly into our bank account. Please use your Order ID as the payment reference. Your order won’t be shipped until the funds have cleared in our account.</p>
									</div>
								</div>
							</li>
						</ul>
					</div>
				</div>
				</div>
			</form>
			</div>
		</div>
	</section>
	<!--checkout Start-->

    <!-- main footer four -->
    <section class="footer-v4">
        <div class="footer-top">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-4 text-column">
                        <h4 class="title">Sign up for our <br>newsletter</h4>
                    </div>
                    <div class="col-lg-8 contact-info">
                        <div class="inner-box">
                            <p>Stay up to update with our latest news and products.</p>
                            <form>
                                <input type="text" name="email" placeholder="Enter your email address...">
                                <button type="submit">Subscribe</button>
                            </form>
                        </div>
                    </div><!--contact-info-->
                </div>
            </div>
        </div>
        <div class="container py-0">
            <div class="widgets-sections">
                <div class="footer-title text-center wow fadeInUp">
                    <img src="images/logo-v2.png" alt="">
                    <p>Our award-winning, experts customer support <br>is available 7 days a week</p>
                </div>
                <div class="contact-widget row align-items-center justify-content-center">
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInLeft">
                        <figure class="image"><img src="images/resource/phone.png" alt=""></figure>
                        <h6 class="title">+88(9800) 6802</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInUp" data-wow-delay="200ms">
                        <figure class="image"><img src="images/resource/phone-2.png" alt=""></figure>
                        <h6 class="title">Town 24/ United State</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInRight" data-wow-delay="300ms">
                        <figure class="image"><img src="images/resource/phone-3.png" alt=""></figure>
                        <h6 class="title"><a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="e2b79187908c838f87a2868d8f838b8ccc818d8f">[email&nbsp;protected]</a></h6>
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-md-4 copyright-text text-center text-lg-start">
                        <p>Copyright © reserved by . koresolution.</p>
                    </div>
                    <div class="col-md-4 social-column text-center">
                        <ul class="social-links">
                            <li><a href="#" title=""><i class="fab fa-facebook-square"></i></a></li>
                            <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                            <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                        </ul>
                    </div>
                    <div class="col-md-4 links-column text-center text-lg-end">
                        <ul class="other-links">
                            <li><a href="#" title="">About</a></li>
                            <li><a href="#" title="">Terms</a></li>
                            <li><a href="#" title="">privacy policy</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End footer section -->

</div><!-- End Page Wrapper -->


<!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target" data-target="html"><span class="fa fa-angle-up"></span></div>


<script data-cfasync="false" src="../../cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script><script src="js/jquery.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/jquery.fancybox.js"></script>
<script src="js/jquery-ui.js"></script>
<script src="js/jquery.countdown.js"></script>
<script src="js/bxslider.js"></script>
<script src="js/wow.js"></script>
<script src="js/appear.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/script.js"></script>



<script id="custom-js" src="js/code_editor_scripts.js?hF5kvS8i"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/shop-checkout.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:46 GMT --></html>